@@ -36,6 +36,8 @@ struct _JammoMentorPrivate {
 	gulong stage_captured_event_handler_id;
 	guint timeout_event_source_id;
 	time_t last_activity_time;
+	
+	guint idle_speech_spoken : 1;
 };
 
 static void speak(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCallback callback, gpointer user_data);
@@ -115,6 +117,7 @@ void jammo_mentor_set_idle_speech(JammoMentor* mentor, const gchar* speech) {
 	if (g_strcmp0(mentor->priv->idle_speech, speech)) {
 		g_free(mentor->priv->idle_speech);
 		mentor->priv->idle_speech = g_strdup(speech);
+		mentor->priv->idle_speech_spoken = FALSE;
 		set_idle_timeout(mentor, TRUE);
 		g_object_notify(G_OBJECT(mentor), "idle-speech");
 	}
@@ -305,7 +308,7 @@ static void on_sample_stopped(JammoSample* sample, gpointer user_data) {
 	g_object_unref(mentor->priv->active_sample);
 	mentor->priv->active_sample = NULL;
 
-	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1500, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
+	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1000, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
 
 	set_idle_timeout(mentor, TRUE);
 	
@@ -335,7 +338,7 @@ static void speak(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCal
 	vault = tangle_vault_new(4, JAMMO_TYPE_MENTOR, mentor, G_TYPE_POINTER, callback, G_TYPE_STRING, speech, G_TYPE_POINTER, user_data);
 	tangle_signal_connect_vault(mentor->priv->active_sample, "stopped", G_CALLBACK(on_sample_stopped), vault);
 	
-	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1500, "scale-x", mentor->priv->active_scale, "scale-y", mentor->priv->active_scale, NULL);
+	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1000, "scale-x", mentor->priv->active_scale, "scale-y", mentor->priv->active_scale, NULL);
 	
 	jammo_sample_play(mentor->priv->active_sample);
 }
@@ -358,6 +361,8 @@ static gboolean on_timeout(gpointer user_data) {
 	
 	elapsed_time = time(NULL) - mentor->priv->last_activity_time;
 	if (elapsed_time >= mentor->priv->idle_timeout) {
+		mentor->priv->timeout_event_source_id = 0;
+		mentor->priv->idle_speech_spoken = TRUE;
 		speak(mentor, mentor->priv->idle_speech, NULL, NULL);
 	} else {
 		mentor->priv->timeout_event_source_id = g_timeout_add((mentor->priv->idle_timeout - elapsed_time) * 1000, on_timeout, mentor);
@@ -372,7 +377,7 @@ static void set_idle_timeout(JammoMentor* mentor, gboolean activate) {
 		mentor->priv->timeout_event_source_id = 0;
 	}
 	
-	if (activate && mentor->priv->idle_timeout && mentor->priv->idle_speech && !mentor->priv->active_sample && CLUTTER_ACTOR_IS_VISIBLE(mentor)) {
+	if (activate && mentor->priv->idle_timeout && mentor->priv->idle_speech && !mentor->priv->idle_speech_spoken && !mentor->priv->active_sample && CLUTTER_ACTOR_IS_VISIBLE(mentor)) {
 		if (!mentor->priv->stage && (mentor->priv->stage = clutter_actor_get_stage(CLUTTER_ACTOR(mentor)))) {
 			mentor->priv->stage_captured_event_handler_id = g_signal_connect(mentor->priv->stage, "captured-event", G_CALLBACK(on_stage_captured_event), mentor);
 		}
