@@ -32,7 +32,6 @@
 
 #ifdef N900
 #include <libosso.h>
-#include <clutter/x11/clutter-x11.h>
 #endif
 
 
@@ -107,7 +106,6 @@ static void add_search_paths(ClutterScript* script) {
 }
 
 #ifdef N900
-
 static gboolean pause_display_blanking(gpointer user_data) {
 	osso_context_t* osso_context;
 	
@@ -117,40 +115,6 @@ static gboolean pause_display_blanking(gpointer user_data) {
 	
 	return TRUE;
 }
-
-static gint rpc_callback(const gchar* interface, const gchar* method, GArray* arguments, gpointer user_data, osso_rpc_t* retval) {
-	ClutterStage* stage;
-	Display* display;
-	Window window;
-	XEvent event;
-
-	stage = CLUTTER_STAGE(user_data);
-	
-	if (!strcmp(interface, "org.umsic.jammo") && !strcmp(method, "top_application")) {
-		display = clutter_x11_get_default_display();
-		window = clutter_x11_get_stage_window(stage);
-
-		/* Fremantle window manager does not obey XRaiseWindow...
-		XRaiseWindow(display, window);
-		... but reacts on _NET_ACTIVE_WINDOW messages (based on qt for maemo code). */
-		event.xclient.type = ClientMessage;
-		event.xclient.message_type = XInternAtom(display, "_NET_ACTIVE_WINDOW", False);
-		event.xclient.display = display;
-		event.xclient.window = window;
-		event.xclient.format = 32;
-		event.xclient.data.l[0] = 1;
-		event.xclient.data.l[1] = clutter_x11_get_current_event_time();
-		event.xclient.data.l[2] = None;
-		event.xclient.data.l[3] = 0;
-		event.xclient.data.l[4] = 0;
-		XSendEvent(display, clutter_x11_get_root_window(), False, SubstructureNotifyMask | SubstructureRedirectMask, &event);
-	}
-	
-	retval->type = DBUS_TYPE_INVALID;
-	
-	return OSSO_OK;
-}
-
 #endif
 
 /* Be sure there are needed place to save compositions and singings.
@@ -204,6 +168,7 @@ int main(int argc, char** argv) {
 	/* TODO: Temporary: make sure Mentor classes exists. */
 	type = JAMMO_TYPE_MENTOR;
 	type = JAMMO_TYPE_MENTOR_ACTION;
+	printf("%p %p\n", JAMMO_TYPE_MENTOR, JAMMO_TYPE_MENTOR_ACTION);
 
 	if ((stylesheet = get_jammo_stylesheet())) {
 		tangle_stylesheet_set_default(stylesheet);
@@ -242,8 +207,6 @@ int main(int argc, char** argv) {
 	clutter_stage_set_key_focus(CLUTTER_STAGE(stage), NULL);
 
 #ifdef N900
-	g_assert(osso_rpc_set_default_cb_f(osso_context, rpc_callback, stage) == OSSO_OK);
-	
 	clutter_stage_set_fullscreen(CLUTTER_STAGE(stage), TRUE);
 #else
 	clutter_actor_set_size(stage, 800, 480);
