@@ -18,6 +18,7 @@
 
 #include "../meam/jammo-recording-track.h"
 #include "jammo-mentor.h"
+#include "jammo-cursor.h"
 #include "../meam/jammo-playing-track.h"
 
 static JammoSequencer* singinggame_sequencer = NULL; //used for stopping
@@ -28,6 +29,46 @@ static ClutterActor *contour_trace;
 static ClutterActor *singinggame_display_freq;
 
 
+static void add_cursor(ClutterColor* color, JammoSequencer* sequencer, ClutterActor* parent) {
+	ClutterActor *container = tangle_widget_new();
+	ClutterActor* texture_color;
+	ClutterActor* texture_image;
+	ClutterActor* cursor;
+
+	//Try to use song's own cursor.png
+	gchar* filepath1 = g_strdup_printf("%s/songs/%s/cursor.png", DATA_DIR,chum_get_current_song());
+	int fd = open(filepath1,O_RDONLY);
+	if (fd == -1) //File not found
+		{
+		printf("file '%s' not found\n",filepath1);
+		ClutterColor transparency = { 0, 0, 0, 0 };
+		texture_image = clutter_rectangle_new_with_color(&transparency);
+		clutter_actor_set_size(texture_image, 60.0,60.0);
+		}
+	else
+		{
+		texture_image = clutter_texture_new();
+		clutter_texture_set_from_file (CLUTTER_TEXTURE (texture_image), filepath1, NULL);
+		}
+	g_free(filepath1);
+	
+	gfloat width,height;
+	clutter_actor_get_size(texture_image, &width, &height);
+	
+	texture_color = clutter_rectangle_new_with_color(color);
+	clutter_actor_set_size(texture_color, width+4,height+4); //slightly bigger than image
+	
+	tangle_widget_add(TANGLE_WIDGET(container), texture_color, NULL);
+	tangle_widget_add(TANGLE_WIDGET(container), texture_image, NULL);
+	
+	
+	cursor = jammo_cursor_new(sequencer, container);
+	tangle_actor_set_depth_position(TANGLE_ACTOR(cursor), 1);
+	clutter_actor_set_position(cursor, 0.0, 480.0-height-2);
+	clutter_actor_set_size(cursor, 800.0, height+4);
+	clutter_container_add_actor(CLUTTER_CONTAINER(parent), cursor);
+}
+
 /*
 This will be more fancier some day.
 */
@@ -163,7 +204,11 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 
 
 
-static void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer none) {
+static void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user_data) {
+	ClutterActor* view;
+	
+	view = CLUTTER_ACTOR(user_data);
+
 	printf("Sequencer stopped_recording\n");
 
 	
@@ -206,7 +251,8 @@ static void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpoint
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(playing_track2));  
 	g_free(loaded_filename);
 
-	
+	ClutterColor green = { 0, 255, 0, 128 };
+	add_cursor(&green, sequencer, view);
 
 
 	chum_set_state_of_chum(SCREEN_PLAY_RECORDED);
@@ -229,8 +275,14 @@ void singinggame_song_click(TangleAction *action, GObject *source, const gchar *
 	chum_set_current_song(song_name);
 	
 
+	gchar* name_of_view;
+	name_of_view = g_strdup_printf("song-%s-view", name );
+	ClutterActor* view = jammo_get_actor_by_id(name_of_view);
+	g_free(name_of_view);
+
+
 	JammoSequencer* sequencer = jammo_sequencer_new();
-	g_signal_connect(sequencer, "stopped", G_CALLBACK(on_sequencer_stopped_recording),NULL);
+	g_signal_connect(sequencer, "stopped", G_CALLBACK(on_sequencer_stopped_recording),view);
 
 	gchar *filename;
 	int fd;
@@ -276,12 +328,6 @@ void singinggame_song_click(TangleAction *action, GObject *source, const gchar *
 
 
 
-	gchar* name_of_view;
-	name_of_view = g_strdup_printf("song-%s-view", name );
-	ClutterActor* view = jammo_get_actor_by_id(name_of_view);
-	g_free(name_of_view);
-
-
 	//g_signal_connect(view, "transition-completed", G_CALLBACK(song_view_showed), sequencer); FIXME: this needs modifications to json
 	song_view_showed(NULL,NULL,NULL,sequencer);
 
@@ -342,7 +388,10 @@ void singinggame_song_click(TangleAction *action, GObject *source, const gchar *
 	g_free(filepath1);
 	#endif /*OFFICIAL_RELEASE */
 	
+	/* Cursor (modified from themeselection.c) */
 
+	ClutterColor red = { 255, 0, 0, 128 };
+	add_cursor(&red, sequencer, view);
 }
 
 
@@ -363,6 +412,7 @@ void singinggame_cross_click(TangleAction *action, GObject *source, const gchar
 
 
 void singinggame_start_songselection(){
+	printf("\n\nDimming\n");
 	//Add transperency to songs which do not have current language vocal-track.
 	//Hide advanced songs, when game level is easy.
 	///////////////////////////////////////////////////////////////////////////////
@@ -431,6 +481,25 @@ void singinggame_start_songselection(){
 		clutter_actor_set_size(container, 670.0, 600);  //Three rows
 
 	g_list_free(songlist);
+	
+	if (!chum_is_easy_game()) //If game level is advanced, tell different instructions ( about scrolling )
+		{ 
+			jammo_mentor_speak_once(jammo_mentor_get_default(),"/opt/jammo/mentor_speech/mentor_songselection_welcome_advanced_fi.ogg");
+		}
+}
+
+
+
+static gulong handler_for_mentor_say_selected;
+
+static void mentor_say_what_is_selected(TangleActor *actor, ClutterActorBox *arg1, gpointer user_data){
+	//printf("got '%s'\n",(gchar*)user_data);
+	gchar *filepath1;
+	filepath1 =  g_strdup_printf("/opt/jammo/mentor_speech/mentor%s_selected_fi.ogg", (gchar*)user_data);
+
+	jammo_mentor_speak(jammo_mentor_get_default(), filepath1);
+	g_free(filepath1);
+	g_signal_handler_disconnect (actor,handler_for_mentor_say_selected);
 }
 
 void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
@@ -438,32 +507,32 @@ void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gch
 	const gchar* name = clutter_actor_get_name(ct);
 	printf("duetto clicked. get_name: '%s'\n",name);
 	
+	ClutterActor* view = jammo_get_actor_by_id("songselection-view");
 	if (strcmp(name,"duetto")==0)
-			chum_set_duetto(TRUE);
+		{
+		chum_set_duetto(TRUE);
+		}
 	else
-			chum_set_duetto(FALSE); //This could also hide language selection
-
-	gchar *filepath1;
-	filepath1 =  g_strdup_printf("/opt/jammo/mentor_speech/mentor_%s_selected_fi.ogg", name);
-	//printf("pass to mentor: '%s' \n",filepath1);
-
-	jammo_mentor_speak(jammo_mentor_get_default(), filepath1);
-
-
+		{
+		chum_set_duetto(FALSE);
+		}
+	gchar *new_name;
+	new_name =  g_strdup_printf("_%s", name);
+	handler_for_mentor_say_selected=g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected), (gpointer)new_name);
+	
+	
 	ClutterActor* button;
 	ClutterActor* texture;
-	gchar *new_name = g_strdup_printf("songselection-%s-icon-texture",name);
+	new_name = g_strdup_printf("songselection-%s-icon-texture",name);
 
 	button = jammo_get_actor_by_id("songselection-duetto");
 	texture = jammo_get_actor_by_id(new_name);
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), texture);
-	
+	g_free(new_name);
 }
 
 
 
-
-
 void singinggame_language_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	ClutterActor* ct =CLUTTER_ACTOR(source);
 	const gchar* name = clutter_actor_get_name(ct);
@@ -471,13 +540,8 @@ void singinggame_language_clicked(TangleAction *action, GObject *source, const g
 
 	chum_set_selected_language(name);
 
-
-	gchar *filepath1;
-	filepath1 =  g_strdup_printf("/opt/jammo/mentor_speech/mentor%s_selected_fi.ogg", name);
-	//printf("pass to mentor: '%s' \n",filepath1);
-
-	jammo_mentor_speak(jammo_mentor_get_default(), filepath1);
-
+	ClutterActor* view = jammo_get_actor_by_id("songselection-view");
+	handler_for_mentor_say_selected = g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected), (gpointer)name);
 	
 	ClutterActor* button;
 	ClutterActor* texture;
@@ -486,13 +550,7 @@ void singinggame_language_clicked(TangleAction *action, GObject *source, const g
 	button = jammo_get_actor_by_id("songselection-language");
 	texture = jammo_get_actor_by_id(new_name);
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), texture);
-
-
-	ClutterActor* view;
-	if ((view = jammo_get_actor_by_id("language-selection-view"))) {
-		clutter_actor_hide(view);
-	}
-
+	g_free(new_name);
 }
 
 
