@@ -6,12 +6,12 @@ This file is for clutter based gui.
 #ifndef _MIDI_EDITOR_H_
 #define _MIDI_EDITOR_H_
 
-
-void start_midi_editor();
+gboolean start_midi_editor();
 void createNote(void);
 void note_pressed(ClutterActor *actor, ClutterEvent *event, gpointer data);
 void note_released(ClutterActor *actor, ClutterEvent *event, gpointer data);
 void note_motion(ClutterActor *actor, ClutterEvent *event, gpointer data);
+void grid_motion(ClutterActor *actor, ClutterEvent *event, gpointer data);
 
 #endif /* MIDI_EDITOR_H */
 
