@@ -42,6 +42,13 @@ static void on_pitch_detected(JammoTrack* track, gfloat frequency, gpointer user
 	g_print("Frequency: %f\n", frequency);
 }
 
+static void on_duration_notify(GObject* object, GParamSpec* param_spec, gpointer user_data) {
+	guint64 duration;
+	
+	g_object_get(object, "duration", &duration, NULL);
+	printf("Duration: %lu ms\n", (gulong)(duration / 1000000));
+}
+
 int main(int argc, char** argv) {
 	GMainLoop* main_loop;
 	JammoSequencer* sequencer;
@@ -55,6 +62,7 @@ int main(int argc, char** argv) {
 	g_signal_connect(sequencer, "stopped", G_CALLBACK(on_sequencer_stopped), main_loop);
 
 	playing_track = jammo_playing_track_new("/opt/jammo/themes/city/110/backing_track.wav");
+	g_signal_connect(playing_track, "notify::duration", G_CALLBACK(on_duration_notify), NULL);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(playing_track));
 	
 	recording_track = jammo_recording_track_new_with_pitch_detect(RECORDING_FILENAME);
